class PostingMode:
    """This object represents a 1C document posting modes ."""

    UNPOST = 'UNPOST'
    """:obj:`str`: 'Markdown'"""
    POST = 'POST'
    """:obj:`str`: 'HTML'"""
    OPER = 'OPER'
    """:obj:`str`: 'HTML'"""
